@@ -399,6 +399,16 @@ class Attachment(Errorable):
             return True
         return False
 
+    def __getstate__(self):
+        """Serialize this object (pickle support)."""
+        return self.pb.SerializeToString()
+
+    def __setstate__(self, state):
+        """Deserialize this object (pickle support)."""
+        pb = service_pb2.Attachment()
+        pb.ParseFromString(state)
+        self.__init__(pb)
+
 
 class Service(Errorable):
     """Service class to use within a bss/oss data source."""
